#!/bin/sh

#ln -s ../../../include/Defn.h
#ln -s ../../../include/Errormsg.h
ln -s ../../../main/hashtable.c
ln -s ../../../main/hashtable.h
#ln -s ../../../include/Internal.h
ln -s ../../../main/mpspawn.c
ln -s ../../../main/peval.c
ln -s ../../../main/peval.h
#ln -s ../../../include/Rconnections.h
ln -s ../../../main/scheduler.c
ln -s ../../../main/scheduler.h
ln -s ../../../main/worker.c

